"""
    Cisco SD-WAN vManage API

    The vManage API exposes the functionality of operations maintaining devices and the overlay network  # noqa: E501

    The version of the OpenAPI document: 2.0.0
    Contact: vmanage@cisco.com
    Generated by: https://openapi-generator.tech
"""


import unittest

import openapi_client
from openapi_client.api.tag_api import TagApi  # noqa: E501


class TestTagApi(unittest.TestCase):
    """TagApi unit test stubs"""

    def setUp(self):
        self.api = TagApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_check_for_conflicts_when_tagging(self):
        """Test case for check_for_conflicts_when_tagging

        """
        pass

    def test_check_rules(self):
        """Test case for check_rules

        """
        pass

    def test_create_tag(self):
        """Test case for create_tag

        """
        pass

    def test_create_tag_rule(self):
        """Test case for create_tag_rule

        """
        pass

    def test_delete_tag(self):
        """Test case for delete_tag

        """
        pass

    def test_delete_tag_rule(self):
        """Test case for delete_tag_rule

        """
        pass

    def test_edit_tag_rule(self):
        """Test case for edit_tag_rule

        """
        pass

    def test_get_tag(self):
        """Test case for get_tag

        """
        pass

    def test_get_tag_rules(self):
        """Test case for get_tag_rules

        """
        pass

    def test_reindex_tag(self):
        """Test case for reindex_tag

        """
        pass


if __name__ == '__main__':
    unittest.main()



"""
    Cisco SD-WAN vManage API

    The vManage API exposes the functionality of operations maintaining devices and the overlay network  # noqa: E501

    The version of the OpenAPI document: 2.0.0
    Contact: vmanage@cisco.com
    Generated by: https://openapi-generator.tech
"""


import unittest

import openapi_client
from openapi_client.api.monitoring_cflowd_flows_api import MonitoringCflowdFlowsApi  # noqa: E501


class TestMonitoringCflowdFlowsApi(unittest.TestCase):
    """MonitoringCflowdFlowsApi unit test stubs"""

    def setUp(self):
        self.api = MonitoringCflowdFlowsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_create_cflow_collector_list(self):
        """Test case for create_cflow_collector_list

        """
        pass

    def test_create_cflowd_collector_list(self):
        """Test case for create_cflowd_collector_list

        """
        pass

    def test_create_cflowd_flows_count_list(self):
        """Test case for create_cflowd_flows_count_list

        """
        pass

    def test_create_cflowd_statistics(self):
        """Test case for create_cflowd_statistics

        """
        pass

    def test_create_cflowd_template(self):
        """Test case for create_cflowd_template

        """
        pass

    def test_get_cflowd_dpi_device_field_json(self):
        """Test case for get_cflowd_dpi_device_field_json

        """
        pass

    def test_get_cflowd_dpi_field_json(self):
        """Test case for get_cflowd_dpi_field_json

        """
        pass

    def test_get_fn_f_cache_stats(self):
        """Test case for get_fn_f_cache_stats

        """
        pass

    def test_get_fn_f_export_client_stats(self):
        """Test case for get_fn_f_export_client_stats

        """
        pass

    def test_get_fn_f_export_stats(self):
        """Test case for get_fn_f_export_stats

        """
        pass

    def test_get_fn_f_monitor_stats(self):
        """Test case for get_fn_f_monitor_stats

        """
        pass

    def test_get_fnf(self):
        """Test case for get_fnf

        """
        pass


if __name__ == '__main__':
    unittest.main()



"""
    Cisco SD-WAN vManage API

    The vManage API exposes the functionality of operations maintaining devices and the overlay network  # noqa: E501

    The version of the OpenAPI document: 2.0.0
    Contact: vmanage@cisco.com
    Generated by: https://openapi-generator.tech
"""


import unittest

import openapi_client
from openapi_client.api.umbrella_api import UmbrellaApi  # noqa: E501


class TestUmbrellaApi(unittest.TestCase):
    """UmbrellaApi unit test stubs"""

    def setUp(self):
        self.api = UmbrellaApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_get_all_keys_from_umbrella(self):
        """Test case for get_all_keys_from_umbrella

        """
        pass

    def test_get_management_keys_from_umbrella(self):
        """Test case for get_management_keys_from_umbrella

        """
        pass

    def test_get_network_keys_from_umbrella(self):
        """Test case for get_network_keys_from_umbrella

        """
        pass

    def test_get_reporting_keys_from_umbrella(self):
        """Test case for get_reporting_keys_from_umbrella

        """
        pass


if __name__ == '__main__':
    unittest.main()



"""
    Cisco SD-WAN vManage API

    The vManage API exposes the functionality of operations maintaining devices and the overlay network  # noqa: E501

    The version of the OpenAPI document: 2.0.0
    Contact: vmanage@cisco.com
    Generated by: https://openapi-generator.tech
"""


import re  # noqa: F401
import sys  # noqa: F401

from openapi_client.api_client import ApiClient, Endpoint as _Endpoint
from openapi_client.model_utils import (  # noqa: F401
    check_allowed_values,
    check_validations,
    date,
    datetime,
    file_type,
    none_type,
    validate_and_convert_types
)


class ColocationClusterApi(object):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client
        self.acitvate_cloud_dock_cluster_endpoint = _Endpoint(
            settings={
                'response_type': ({str: (bool, date, datetime, dict, float, int, list, str, none_type)},),
                'auth': [],
                'endpoint_path': '/colocation/cluster/activate',
                'operation_id': 'acitvate_cloud_dock_cluster',
                'http_method': 'POST',
                'servers': None,
            },
            params_map={
                'all': [
                    'cluster_name',
                ],
                'required': [
                    'cluster_name',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'cluster_name':
                        (str,),
                },
                'attribute_map': {
                    'cluster_name': 'clusterName',
                },
                'location_map': {
                    'cluster_name': 'query',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [],
            },
            api_client=api_client
        )
        self.cloud_dock_cluster_preview_endpoint = _Endpoint(
            settings={
                'response_type': (str,),
                'auth': [],
                'endpoint_path': '/colocation/cluster/config',
                'operation_id': 'cloud_dock_cluster_preview',
                'http_method': 'GET',
                'servers': None,
            },
            params_map={
                'all': [
                    'serial_number',
                ],
                'required': [
                    'serial_number',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'serial_number':
                        (str,),
                },
                'attribute_map': {
                    'serial_number': 'serialNumber',
                },
                'location_map': {
                    'serial_number': 'query',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'text/plain'
                ],
                'content_type': [],
            },
            api_client=api_client
        )
        self.create_cloud_dock_cluster_endpoint = _Endpoint(
            settings={
                'response_type': None,
                'auth': [],
                'endpoint_path': '/colocation/cluster',
                'operation_id': 'create_cloud_dock_cluster',
                'http_method': 'POST',
                'servers': None,
            },
            params_map={
                'all': [
                    'body',
                ],
                'required': [],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'body':
                        ({str: (bool, date, datetime, dict, float, int, list, str, none_type)},),
                },
                'attribute_map': {
                },
                'location_map': {
                    'body': 'body',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [],
                'content_type': [
                    'application/json'
                ]
            },
            api_client=api_client
        )
        self.de_acitvate_cloud_dock_cluster_endpoint = _Endpoint(
            settings={
                'response_type': None,
                'auth': [],
                'endpoint_path': '/colocation/cluster/deactivate',
                'operation_id': 'de_acitvate_cloud_dock_cluster',
                'http_method': 'POST',
                'servers': None,
            },
            params_map={
                'all': [
                    'cluster_id',
                ],
                'required': [
                    'cluster_id',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'cluster_id':
                        (str,),
                },
                'attribute_map': {
                    'cluster_id': 'clusterId',
                },
                'location_map': {
                    'cluster_id': 'query',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [],
                'content_type': [],
            },
            api_client=api_client
        )
        self.delete_cloud_dock_cluster_by_name_endpoint = _Endpoint(
            settings={
                'response_type': None,
                'auth': [],
                'endpoint_path': '/colocation/cluster/{clustername}',
                'operation_id': 'delete_cloud_dock_cluster_by_name',
                'http_method': 'DELETE',
                'servers': None,
            },
            params_map={
                'all': [
                    'clustername',
                ],
                'required': [
                    'clustername',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'clustername':
                        (str,),
                },
                'attribute_map': {
                    'clustername': 'clustername',
                },
                'location_map': {
                    'clustername': 'path',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [],
                'content_type': [],
            },
            api_client=api_client
        )
        self.dummyccm_endpoint = _Endpoint(
            settings={
                'response_type': None,
                'auth': [],
                'endpoint_path': '/colocation/cluster/activateClusterDummy',
                'operation_id': 'dummyccm',
                'http_method': 'GET',
                'servers': None,
            },
            params_map={
                'all': [
                    'cluster_name',
                ],
                'required': [
                    'cluster_name',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'cluster_name':
                        (str,),
                },
                'attribute_map': {
                    'cluster_name': 'clusterName',
                },
                'location_map': {
                    'cluster_name': 'query',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [],
                'content_type': [],
            },
            api_client=api_client
        )
        self.dummycsp_state_endpoint = _Endpoint(
            settings={
                'response_type': None,
                'auth': [],
                'endpoint_path': '/colocation/cluster/activateClusterDummyState',
                'operation_id': 'dummycsp_state',
                'http_method': 'GET',
                'servers': None,
            },
            params_map={
                'all': [
                    'cluster_name',
                    'state',
                ],
                'required': [
                    'cluster_name',
                    'state',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'cluster_name':
                        (str,),
                    'state':
                        (str,),
                },
                'attribute_map': {
                    'cluster_name': 'clusterName',
                    'state': 'state',
                },
                'location_map': {
                    'cluster_name': 'query',
                    'state': 'query',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [],
                'content_type': [],
            },
            api_client=api_client
        )
        self.get_cloud_dock_cluster_detail_endpoint = _Endpoint(
            settings={
                'response_type': ({str: (bool, date, datetime, dict, float, int, list, str, none_type)},),
                'auth': [],
                'endpoint_path': '/colocation/cluster',
                'operation_id': 'get_cloud_dock_cluster_detail',
                'http_method': 'GET',
                'servers': None,
            },
            params_map={
                'all': [
                    'cluster_name',
                ],
                'required': [
                    'cluster_name',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'cluster_name':
                        (str,),
                },
                'attribute_map': {
                    'cluster_name': 'clusterName',
                },
                'location_map': {
                    'cluster_name': 'query',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [],
            },
            api_client=api_client
        )
        self.get_cloud_dock_cluster_detail_by_id_endpoint = _Endpoint(
            settings={
                'response_type': ({str: (bool, date, datetime, dict, float, int, list, str, none_type)},),
                'auth': [],
                'endpoint_path': '/colocation/cluster/id',
                'operation_id': 'get_cloud_dock_cluster_detail_by_id',
                'http_method': 'GET',
                'servers': None,
            },
            params_map={
                'all': [
                    'cluster_id',
                ],
                'required': [
                    'cluster_id',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'cluster_id':
                        (str,),
                },
                'attribute_map': {
                    'cluster_id': 'clusterId',
                },
                'location_map': {
                    'cluster_id': 'query',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [],
            },
            api_client=api_client
        )
        self.rma_cloud_dock_csp_endpoint = _Endpoint(
            settings={
                'response_type': ({str: (bool, date, datetime, dict, float, int, list, str, none_type)},),
                'auth': [],
                'endpoint_path': '/colocation/cluster/rma',
                'operation_id': 'rma_cloud_dock_csp',
                'http_method': 'POST',
                'servers': None,
            },
            params_map={
                'all': [
                    'cluster_name',
                    'body',
                ],
                'required': [
                    'cluster_name',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'cluster_name':
                        (str,),
                    'body':
                        (str,),
                },
                'attribute_map': {
                    'cluster_name': 'clusterName',
                },
                'location_map': {
                    'cluster_name': 'query',
                    'body': 'body',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [],
            },
            api_client=api_client
        )
        self.update_cloud_dock_cluster_endpoint = _Endpoint(
            settings={
                'response_type': None,
                'auth': [],
                'endpoint_path': '/colocation/cluster',
                'operation_id': 'update_cloud_dock_cluster',
                'http_method': 'PUT',
                'servers': None,
            },
            params_map={
                'all': [
                    'body',
                ],
                'required': [],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'body':
                        ({str: (bool, date, datetime, dict, float, int, list, str, none_type)},),
                },
                'attribute_map': {
                },
                'location_map': {
                    'body': 'body',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [],
                'content_type': [
                    'application/json'
                ]
            },
            api_client=api_client
        )
        self.update_csp_to_cluster_endpoint = _Endpoint(
            settings={
                'response_type': None,
                'auth': [],
                'endpoint_path': '/colocation/cluster/attached/csp',
                'operation_id': 'update_csp_to_cluster',
                'http_method': 'PUT',
                'servers': None,
            },
            params_map={
                'all': [
                    'body',
                ],
                'required': [],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'body':
                        ({str: (bool, date, datetime, dict, float, int, list, str, none_type)},),
                },
                'attribute_map': {
                },
                'location_map': {
                    'body': 'body',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [],
                'content_type': [
                    'application/json'
                ]
            },
            api_client=api_client
        )

    def acitvate_cloud_dock_cluster(
        self,
        cluster_name,
        **kwargs
    ):
        """acitvate_cloud_dock_cluster  # noqa: E501

        Activate a cluster  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.acitvate_cloud_dock_cluster(cluster_name, async_req=True)
        >>> result = thread.get()

        Args:
            cluster_name (str): Cluster name

        Keyword Args:
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            _request_auths (list): set to override the auth_settings for an a single
                request; this effectively ignores the authentication
                in the spec for a single request.
                Default is None
            async_req (bool): execute request asynchronously

        Returns:
            {str: (bool, date, datetime, dict, float, int, list, str, none_type)}
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['_request_auths'] = kwargs.get('_request_auths', None)
        kwargs['cluster_name'] = \
            cluster_name
        return self.acitvate_cloud_dock_cluster_endpoint.call_with_http_info(**kwargs)

    def cloud_dock_cluster_preview(
        self,
        serial_number,
        **kwargs
    ):
        """cloud_dock_cluster_preview  # noqa: E501

        Clouddock cluster preview  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.cloud_dock_cluster_preview(serial_number, async_req=True)
        >>> result = thread.get()

        Args:
            serial_number (str): Serial number

        Keyword Args:
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            _request_auths (list): set to override the auth_settings for an a single
                request; this effectively ignores the authentication
                in the spec for a single request.
                Default is None
            async_req (bool): execute request asynchronously

        Returns:
            str
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['_request_auths'] = kwargs.get('_request_auths', None)
        kwargs['serial_number'] = \
            serial_number
        return self.cloud_dock_cluster_preview_endpoint.call_with_http_info(**kwargs)

    def create_cloud_dock_cluster(
        self,
        **kwargs
    ):
        """create_cloud_dock_cluster  # noqa: E501

        Add a new cluster  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.create_cloud_dock_cluster(async_req=True)
        >>> result = thread.get()


        Keyword Args:
            body ({str: (bool, date, datetime, dict, float, int, list, str, none_type)}): Cluster config. [optional]
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            _request_auths (list): set to override the auth_settings for an a single
                request; this effectively ignores the authentication
                in the spec for a single request.
                Default is None
            async_req (bool): execute request asynchronously

        Returns:
            None
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['_request_auths'] = kwargs.get('_request_auths', None)
        return self.create_cloud_dock_cluster_endpoint.call_with_http_info(**kwargs)

    def de_acitvate_cloud_dock_cluster(
        self,
        cluster_id,
        **kwargs
    ):
        """de_acitvate_cloud_dock_cluster  # noqa: E501

        Deactivate clouddock cluster  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.de_acitvate_cloud_dock_cluster(cluster_id, async_req=True)
        >>> result = thread.get()

        Args:
            cluster_id (str): Cluster Id

        Keyword Args:
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            _request_auths (list): set to override the auth_settings for an a single
                request; this effectively ignores the authentication
                in the spec for a single request.
                Default is None
            async_req (bool): execute request asynchronously

        Returns:
            None
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['_request_auths'] = kwargs.get('_request_auths', None)
        kwargs['cluster_id'] = \
            cluster_id
        return self.de_acitvate_cloud_dock_cluster_endpoint.call_with_http_info(**kwargs)

    def delete_cloud_dock_cluster_by_name(
        self,
        clustername,
        **kwargs
    ):
        """delete_cloud_dock_cluster_by_name  # noqa: E501

        Delete cluster by name  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.delete_cloud_dock_cluster_by_name(clustername, async_req=True)
        >>> result = thread.get()

        Args:
            clustername (str): Cluster name

        Keyword Args:
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            _request_auths (list): set to override the auth_settings for an a single
                request; this effectively ignores the authentication
                in the spec for a single request.
                Default is None
            async_req (bool): execute request asynchronously

        Returns:
            None
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['_request_auths'] = kwargs.get('_request_auths', None)
        kwargs['clustername'] = \
            clustername
        return self.delete_cloud_dock_cluster_by_name_endpoint.call_with_http_info(**kwargs)

    def dummyccm(
        self,
        cluster_name,
        **kwargs
    ):
        """dummyccm  # noqa: E501

        Activate dummp cluster  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.dummyccm(cluster_name, async_req=True)
        >>> result = thread.get()

        Args:
            cluster_name (str): Cluster name

        Keyword Args:
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            _request_auths (list): set to override the auth_settings for an a single
                request; this effectively ignores the authentication
                in the spec for a single request.
                Default is None
            async_req (bool): execute request asynchronously

        Returns:
            None
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['_request_auths'] = kwargs.get('_request_auths', None)
        kwargs['cluster_name'] = \
            cluster_name
        return self.dummyccm_endpoint.call_with_http_info(**kwargs)

    def dummycsp_state(
        self,
        cluster_name,
        state,
        **kwargs
    ):
        """dummycsp_state  # noqa: E501

        Activate cluster in a state  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.dummycsp_state(cluster_name, state, async_req=True)
        >>> result = thread.get()

        Args:
            cluster_name (str): Cluster name
            state (str): Cluster state

        Keyword Args:
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            _request_auths (list): set to override the auth_settings for an a single
                request; this effectively ignores the authentication
                in the spec for a single request.
                Default is None
            async_req (bool): execute request asynchronously

        Returns:
            None
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['_request_auths'] = kwargs.get('_request_auths', None)
        kwargs['cluster_name'] = \
            cluster_name
        kwargs['state'] = \
            state
        return self.dummycsp_state_endpoint.call_with_http_info(**kwargs)

    def get_cloud_dock_cluster_detail(
        self,
        cluster_name,
        **kwargs
    ):
        """get_cloud_dock_cluster_detail  # noqa: E501

        Get details of all existing Clusters  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_cloud_dock_cluster_detail(cluster_name, async_req=True)
        >>> result = thread.get()

        Args:
            cluster_name (str): Cluster name

        Keyword Args:
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            _request_auths (list): set to override the auth_settings for an a single
                request; this effectively ignores the authentication
                in the spec for a single request.
                Default is None
            async_req (bool): execute request asynchronously

        Returns:
            {str: (bool, date, datetime, dict, float, int, list, str, none_type)}
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['_request_auths'] = kwargs.get('_request_auths', None)
        kwargs['cluster_name'] = \
            cluster_name
        return self.get_cloud_dock_cluster_detail_endpoint.call_with_http_info(**kwargs)

    def get_cloud_dock_cluster_detail_by_id(
        self,
        cluster_id,
        **kwargs
    ):
        """get_cloud_dock_cluster_detail_by_id  # noqa: E501

        Get cluster by Id  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_cloud_dock_cluster_detail_by_id(cluster_id, async_req=True)
        >>> result = thread.get()

        Args:
            cluster_id (str): Cluster Id

        Keyword Args:
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            _request_auths (list): set to override the auth_settings for an a single
                request; this effectively ignores the authentication
                in the spec for a single request.
                Default is None
            async_req (bool): execute request asynchronously

        Returns:
            {str: (bool, date, datetime, dict, float, int, list, str, none_type)}
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['_request_auths'] = kwargs.get('_request_auths', None)
        kwargs['cluster_id'] = \
            cluster_id
        return self.get_cloud_dock_cluster_detail_by_id_endpoint.call_with_http_info(**kwargs)

    def rma_cloud_dock_csp(
        self,
        cluster_name,
        **kwargs
    ):
        """rma_cloud_dock_csp  # noqa: E501

        RMA operation for CSP device  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.rma_cloud_dock_csp(cluster_name, async_req=True)
        >>> result = thread.get()

        Args:
            cluster_name (str): Cluster name

        Keyword Args:
            body (str): [optional]
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            _request_auths (list): set to override the auth_settings for an a single
                request; this effectively ignores the authentication
                in the spec for a single request.
                Default is None
            async_req (bool): execute request asynchronously

        Returns:
            {str: (bool, date, datetime, dict, float, int, list, str, none_type)}
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['_request_auths'] = kwargs.get('_request_auths', None)
        kwargs['cluster_name'] = \
            cluster_name
        return self.rma_cloud_dock_csp_endpoint.call_with_http_info(**kwargs)

    def update_cloud_dock_cluster(
        self,
        **kwargs
    ):
        """update_cloud_dock_cluster  # noqa: E501

        Update a existing cluster  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.update_cloud_dock_cluster(async_req=True)
        >>> result = thread.get()


        Keyword Args:
            body ({str: (bool, date, datetime, dict, float, int, list, str, none_type)}): Cluster config. [optional]
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            _request_auths (list): set to override the auth_settings for an a single
                request; this effectively ignores the authentication
                in the spec for a single request.
                Default is None
            async_req (bool): execute request asynchronously

        Returns:
            None
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['_request_auths'] = kwargs.get('_request_auths', None)
        return self.update_cloud_dock_cluster_endpoint.call_with_http_info(**kwargs)

    def update_csp_to_cluster(
        self,
        **kwargs
    ):
        """update_csp_to_cluster  # noqa: E501

        Update attached csp to cluster  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.update_csp_to_cluster(async_req=True)
        >>> result = thread.get()


        Keyword Args:
            body ({str: (bool, date, datetime, dict, float, int, list, str, none_type)}): CSP config. [optional]
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            _request_auths (list): set to override the auth_settings for an a single
                request; this effectively ignores the authentication
                in the spec for a single request.
                Default is None
            async_req (bool): execute request asynchronously

        Returns:
            None
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['_request_auths'] = kwargs.get('_request_auths', None)
        return self.update_csp_to_cluster_endpoint.call_with_http_info(**kwargs)




"""
    Cisco SD-WAN vManage API

    The vManage API exposes the functionality of operations maintaining devices and the overlay network  # noqa: E501

    The version of the OpenAPI document: 2.0.0
    Contact: vmanage@cisco.com
    Generated by: https://openapi-generator.tech
"""


import unittest

import openapi_client
from openapi_client.api.real_time_monitoring_i_psec_api import RealTimeMonitoringIPsecApi  # noqa: E501


class TestRealTimeMonitoringIPsecApi(unittest.TestCase):
    """RealTimeMonitoringIPsecApi unit test stubs"""

    def setUp(self):
        self.api = RealTimeMonitoringIPsecApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_create_crypto_ipsec_identity(self):
        """Test case for create_crypto_ipsec_identity

        """
        pass

    def test_create_cryptov1_local_sa_list(self):
        """Test case for create_cryptov1_local_sa_list

        """
        pass

    def test_create_cryptov2_local_sa_list(self):
        """Test case for create_cryptov2_local_sa_list

        """
        pass

    def test_create_i_psec_pwk_inbound_connections(self):
        """Test case for create_i_psec_pwk_inbound_connections

        """
        pass

    def test_create_i_psec_pwk_local_sa(self):
        """Test case for create_i_psec_pwk_local_sa

        """
        pass

    def test_create_i_psec_pwk_outbound_connections(self):
        """Test case for create_i_psec_pwk_outbound_connections

        """
        pass

    def test_create_ike_inbound_list(self):
        """Test case for create_ike_inbound_list

        """
        pass

    def test_create_ike_outbound_list(self):
        """Test case for create_ike_outbound_list

        """
        pass

    def test_create_ike_sessions(self):
        """Test case for create_ike_sessions

        """
        pass

    def test_create_in_bound_list(self):
        """Test case for create_in_bound_list

        """
        pass

    def test_create_local_sa_list(self):
        """Test case for create_local_sa_list

        """
        pass

    def test_create_out_bound_list(self):
        """Test case for create_out_bound_list

        """
        pass


if __name__ == '__main__':
    unittest.main()



# flake8: noqa

# import all models into this package
# if you have many models here with many references from one model to another this may
# raise a RecursionError
# to avoid this, import only the models that you directly need like:
# from from openapi_client.model.pet import Pet
# or import this package, but before doing it, use:
# import sys
# sys.setrecursionlimit(n)

from openapi_client.model.advanced_radio_setting import AdvancedRadioSetting
from openapi_client.model.api_re_key_device import ApiReKeyDevice
from openapi_client.model.api_re_key_device_list import ApiReKeyDeviceList
from openapi_client.model.aws_iam_credentials import AwsIamCredentials
from openapi_client.model.aws_key_credentials import AwsKeyCredentials
from openapi_client.model.azure_credentials import AzureCredentials
from openapi_client.model.banner import Banner
from openapi_client.model.bfd import Bfd
from openapi_client.model.bfd_timer_on_transport_tunnels import BfdTimerOnTransportTunnels
from openapi_client.model.biz_internet_timer import BizInternetTimer
from openapi_client.model.cellular import Cellular
from openapi_client.model.cellular_all_of import CellularAllOf
from openapi_client.model.cellular_profile import CellularProfile
from openapi_client.model.certificate_states import CertificateStates
from openapi_client.model.certificate_validity import CertificateValidity
from openapi_client.model.channel_power_settings import ChannelPowerSettings
from openapi_client.model.config_group import ConfigGroup
from openapi_client.model.connect_to_ntp_server import ConnectToNtpServer
from openapi_client.model.control_status import ControlStatus
from openapi_client.model.corporate_wifi import CorporateWifi
from openapi_client.model.country_region_settings import CountryRegionSettings
from openapi_client.model.create_device_params import CreateDeviceParams
from openapi_client.model.create_tenant_model import CreateTenantModel
from openapi_client.model.dhcp_pool import DHCPPool
from openapi_client.model.data_center import DataCenter
from openapi_client.model.data_center_registration import DataCenterRegistration
from openapi_client.model.delete_tenant_bulk_model import DeleteTenantBulkModel
from openapi_client.model.delete_tenant_model import DeleteTenantModel
from openapi_client.model.device import Device
from openapi_client.model.device_health_details import DeviceHealthDetails
from openapi_client.model.device_ip import DeviceIP
from openapi_client.model.device_model import DeviceModel
from openapi_client.model.device_type import DeviceType
from openapi_client.model.device_uuid import DeviceUuid
from openapi_client.model.devices_health import DevicesHealth
from openapi_client.model.devices_health_overview import DevicesHealthOverview
from openapi_client.model.disaster_recovery_settings import DisasterRecoverySettings
from openapi_client.model.domain_detail import DomainDetail
from openapi_client.model.entity_ownership_info import EntityOwnershipInfo
from openapi_client.model.equinix_credentials import EquinixCredentials
from openapi_client.model.equinix_location_info import EquinixLocationInfo
from openapi_client.model.equinix_ne_info import EquinixNEInfo
from openapi_client.model.equinix_partner_port import EquinixPartnerPort
from openapi_client.model.ethernet import Ethernet
from openapi_client.model.ethernet_all_of import EthernetAllOf
from openapi_client.model.ethernet_interface import EthernetInterface
from openapi_client.model.event_name import EventName
from openapi_client.model.feature_profile import FeatureProfile
from openapi_client.model.gcp_credentials import GcpCredentials
from openapi_client.model.get_o365_preferred_path_from_v_analytics_request import GetO365PreferredPathFromVAnalyticsRequest
from openapi_client.model.get_o365_preferred_path_from_v_analytics_request_value import GetO365PreferredPathFromVAnalyticsRequestValue
from openapi_client.model.global_settings import GlobalSettings
from openapi_client.model.global_settings_all_of import GlobalSettingsAllOf
from openapi_client.model.group_id import GroupId
from openapi_client.model.guest_wifi import GuestWifi
from openapi_client.model.header import Header
from openapi_client.model.header_element import HeaderElement
from openapi_client.model.host import Host
from openapi_client.model.ike_phase import IkePhase
from openapi_client.model.ip_sec_policy import IpSecPolicy
from openapi_client.model.ip_sec_security import IpSecSecurity
from openapi_client.model.logging_system_messages import LoggingSystemMessages
from openapi_client.model.login_access_to_router import LoginAccessToRouter
from openapi_client.model.lte_timer import LteTimer
from openapi_client.model.megaport_credentials import MegaportCredentials
from openapi_client.model.megaport_location_info import MegaportLocationInfo
from openapi_client.model.megaport_mve_info import MegaportMVEInfo
from openapi_client.model.megaport_partner_port import MegaportPartnerPort
from openapi_client.model.mpls_timer import MplsTimer
from openapi_client.model.multi_cloud_account_info import MultiCloudAccountInfo
from openapi_client.model.multi_cloud_edge_account_info import MultiCloudEdgeAccountInfo
from openapi_client.model.multi_cloud_edge_billing_account_info import MultiCloudEdgeBillingAccountInfo
from openapi_client.model.multi_cloud_edge_location_info import MultiCloudEdgeLocationInfo
from openapi_client.model.multi_cloud_edge_partner_port import MultiCloudEdgePartnerPort
from openapi_client.model.nat_rule import NATRule
from openapi_client.model.name_value_pair import NameValuePair
from openapi_client.model.network_protocol import NetworkProtocol
from openapi_client.model.network_protocol_all_of import NetworkProtocolAllOf
from openapi_client.model.node import Node
from openapi_client.model.nwpi_domain_monitor import NwpiDomainMonitor
from openapi_client.model.omp import OMP
from openapi_client.model.on_demand_queue_entry import OnDemandQueueEntry
from openapi_client.model.partner_type import PartnerType
from openapi_client.model.policy_rule import PolicyRule
from openapi_client.model.profile_parcel import ProfileParcel
from openapi_client.model.property_definition import PropertyDefinition
from openapi_client.model.public_internet_timer import PublicInternetTimer
from openapi_client.model.queue_entries import QueueEntries
from openapi_client.model.queue_properties import QueueProperties
from openapi_client.model.radio_band_setting24_g import RadioBandSetting24G
from openapi_client.model.radio_band_setting5_g import RadioBandSetting5G
from openapi_client.model.radius_server import RadiusServer
from openapi_client.model.resource_group import ResourceGroup
from openapi_client.model.ssid_config import SSIDConfig
from openapi_client.model.schema_definition import SchemaDefinition
from openapi_client.model.security_policy import SecurityPolicy
from openapi_client.model.security_policy_all_of import SecurityPolicyAllOf
from openapi_client.model.sim_slot_config import SimSlotConfig
from openapi_client.model.site_health import SiteHealth
from openapi_client.model.site_to_site_vpn import SiteToSiteVpn
from openapi_client.model.smart_account_model import SmartAccountModel
from openapi_client.model.statistics_processing_counters import StatisticsProcessingCounters
from openapi_client.model.stats_type_processing_counters import StatsTypeProcessingCounters
from openapi_client.model.systems import Systems
from openapi_client.model.tag_restful_resource import TagRestfulResource
from openapi_client.model.tag_restful_resource_all_groups import TagRestfulResourceAllGroups
from openapi_client.model.tenant_status import TenantStatus
from openapi_client.model.tenant_status_list_model import TenantStatusListModel
from openapi_client.model.thread_pool_definition import ThreadPoolDefinition
from openapi_client.model.thread_pools_definition import ThreadPoolsDefinition
from openapi_client.model.update_tenant_model import UpdateTenantModel
from openapi_client.model.uuid import Uuid
from openapi_client.model.uuid_to_domain_id import UuidToDomainId
from openapi_client.model.uuid_to_domain_id_mapping import UuidToDomainIdMapping
from openapi_client.model.v_edge_bootstrap_config import VEdgeBootstrapConfig
from openapi_client.model.v_edge_health import VEdgeHealth
from openapi_client.model.vpnid import VPNID
from openapi_client.model.v_resource_group_name_model import VResourceGroupNameModel
from openapi_client.model.v_smart_status import VSmartStatus
from openapi_client.model.variable import Variable
from openapi_client.model.vertex_definition import VertexDefinition
from openapi_client.model.vpn import Vpn
from openapi_client.model.vpn_all_of import VpnAllOf
from openapi_client.model.wan_spec import WanSpec
from openapi_client.model.wifi import Wifi
from openapi_client.model.wifi_all_of import WifiAllOf



"""
    Cisco SD-WAN vManage API

    The vManage API exposes the functionality of operations maintaining devices and the overlay network  # noqa: E501

    The version of the OpenAPI document: 2.0.0
    Contact: vmanage@cisco.com
    Generated by: https://openapi-generator.tech
"""


import unittest

import openapi_client
from openapi_client.api.real_time_monitoring_trustsec_api import RealTimeMonitoringTrustsecApi  # noqa: E501


class TestRealTimeMonitoringTrustsecApi(unittest.TestCase):
    """RealTimeMonitoringTrustsecApi unit test stubs"""

    def setUp(self):
        self.api = RealTimeMonitoringTrustsecApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_get_cts_pac(self):
        """Test case for get_cts_pac

        """
        pass

    def test_get_environment_data(self):
        """Test case for get_environment_data

        """
        pass

    def test_get_radius_server(self):
        """Test case for get_radius_server

        """
        pass

    def test_get_role_based_counters(self):
        """Test case for get_role_based_counters

        """
        pass

    def test_get_role_based_ipv6_counters(self):
        """Test case for get_role_based_ipv6_counters

        """
        pass

    def test_get_role_based_ipv6_permissions(self):
        """Test case for get_role_based_ipv6_permissions

        """
        pass

    def test_get_role_based_permissions(self):
        """Test case for get_role_based_permissions

        """
        pass

    def test_get_role_based_sgt_map(self):
        """Test case for get_role_based_sgt_map

        """
        pass

    def test_get_sxp_connections(self):
        """Test case for get_sxp_connections

        """
        pass


if __name__ == '__main__':
    unittest.main()



"""
    Cisco SD-WAN vManage API

    The vManage API exposes the functionality of operations maintaining devices and the overlay network  # noqa: E501

    The version of the OpenAPI document: 2.0.0
    Contact: vmanage@cisco.com
    Generated by: https://openapi-generator.tech
"""


import unittest

import openapi_client
from openapi_client.api.default_api import DefaultApi  # noqa: E501


class TestDefaultApi(unittest.TestCase):
    """DefaultApi unit test stubs"""

    def setUp(self):
        self.api = DefaultApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_add_tier(self):
        """Test case for add_tier

        """
        pass

    def test_delete_tier(self):
        """Test case for delete_tier

        """
        pass

    def test_get_o365_preferred_path_from_v_analytics(self):
        """Test case for get_o365_preferred_path_from_v_analytics

        """
        pass

    def test_get_tiers(self):
        """Test case for get_tiers

        """
        pass

    def test_update_device_action_status(self):
        """Test case for update_device_action_status

        """
        pass


if __name__ == '__main__':
    unittest.main()



"""
    Cisco SD-WAN vManage API

    The vManage API exposes the functionality of operations maintaining devices and the overlay network  # noqa: E501

    The version of the OpenAPI document: 2.0.0
    Contact: vmanage@cisco.com
    Generated by: https://openapi-generator.tech
"""


import unittest

import openapi_client
from openapi_client.api.configuration_template_master_api import ConfigurationTemplateMasterApi  # noqa: E501


class TestConfigurationTemplateMasterApi(unittest.TestCase):
    """ConfigurationTemplateMasterApi unit test stubs"""

    def setUp(self):
        self.api = ConfigurationTemplateMasterApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_change_template_resource_group1(self):
        """Test case for change_template_resource_group1

        """
        pass

    def test_create_cli_template(self):
        """Test case for create_cli_template

        """
        pass

    def test_create_master_template(self):
        """Test case for create_master_template

        """
        pass

    def test_delete_master_template(self):
        """Test case for delete_master_template

        """
        pass

    def test_edit_master_template(self):
        """Test case for edit_master_template

        """
        pass

    def test_generate_master_template_list(self):
        """Test case for generate_master_template_list

        """
        pass

    def test_generate_template_for_migration(self):
        """Test case for generate_template_for_migration

        """
        pass

    def test_get_master_template_definition(self):
        """Test case for get_master_template_definition

        """
        pass

    def test_get_out_of_sync_devices(self):
        """Test case for get_out_of_sync_devices

        """
        pass

    def test_get_out_of_sync_templates(self):
        """Test case for get_out_of_sync_templates

        """
        pass

    def test_is_migration_required(self):
        """Test case for is_migration_required

        """
        pass

    def test_migrate_templates(self):
        """Test case for migrate_templates

        """
        pass

    def test_migration_info(self):
        """Test case for migration_info

        """
        pass


if __name__ == '__main__':
    unittest.main()



"""
    Cisco SD-WAN vManage API

    The vManage API exposes the functionality of operations maintaining devices and the overlay network  # noqa: E501

    The version of the OpenAPI document: 2.0.0
    Contact: vmanage@cisco.com
    Generated by: https://openapi-generator.tech
"""


import re  # noqa: F401
import sys  # noqa: F401

from openapi_client.api_client import ApiClient, Endpoint as _Endpoint
from openapi_client.model_utils import (  # noqa: F401
    check_allowed_values,
    check_validations,
    date,
    datetime,
    file_type,
    none_type,
    validate_and_convert_types
)


class MonitoringStatsProcessingApi(object):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client
        self.enable_statistics_demo_mode_endpoint = _Endpoint(
            settings={
                'response_type': ({str: (bool, date, datetime, dict, float, int, list, str, none_type)},),
                'auth': [],
                'endpoint_path': '/statistics/demomode',
                'operation_id': 'enable_statistics_demo_mode',
                'http_method': 'GET',
                'servers': None,
            },
            params_map={
                'all': [
                    'enable',
                ],
                'required': [],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'enable':
                        (bool,),
                },
                'attribute_map': {
                    'enable': 'enable',
                },
                'location_map': {
                    'enable': 'query',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [],
            },
            api_client=api_client
        )
        self.generate_stats_collect_thread_report_endpoint = _Endpoint(
            settings={
                'response_type': ([{str: (bool, date, datetime, dict, float, int, list, str, none_type)}],),
                'auth': [],
                'endpoint_path': '/statistics/collect/thread/status',
                'operation_id': 'generate_stats_collect_thread_report',
                'http_method': 'GET',
                'servers': None,
            },
            params_map={
                'all': [
                ],
                'required': [],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                },
                'attribute_map': {
                },
                'location_map': {
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [],
            },
            api_client=api_client
        )
        self.generate_stats_process_report_endpoint = _Endpoint(
            settings={
                'response_type': ([{str: (bool, date, datetime, dict, float, int, list, str, none_type)}],),
                'auth': [],
                'endpoint_path': '/statistics/process/status',
                'operation_id': 'generate_stats_process_report',
                'http_method': 'GET',
                'servers': None,
            },
            params_map={
                'all': [
                    'process_queue',
                ],
                'required': [],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'process_queue':
                        (int,),
                },
                'attribute_map': {
                    'process_queue': 'processQueue',
                },
                'location_map': {
                    'process_queue': 'query',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [],
            },
            api_client=api_client
        )
        self.generate_stats_process_thread_report_endpoint = _Endpoint(
            settings={
                'response_type': ([{str: (bool, date, datetime, dict, float, int, list, str, none_type)}],),
                'auth': [],
                'endpoint_path': '/statistics/process/thread/status',
                'operation_id': 'generate_stats_process_thread_report',
                'http_method': 'GET',
                'servers': None,
            },
            params_map={
                'all': [
                ],
                'required': [],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                },
                'attribute_map': {
                },
                'location_map': {
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [],
            },
            api_client=api_client
        )
        self.get_statistic_type_endpoint = _Endpoint(
            settings={
                'response_type': ([{str: (bool, date, datetime, dict, float, int, list, str, none_type)}],),
                'auth': [],
                'endpoint_path': '/statistics',
                'operation_id': 'get_statistic_type',
                'http_method': 'GET',
                'servers': None,
            },
            params_map={
                'all': [
                ],
                'required': [],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                },
                'attribute_map': {
                },
                'location_map': {
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [],
            },
            api_client=api_client
        )
        self.get_statistics_processing_counters_endpoint = _Endpoint(
            settings={
                'response_type': ([{str: (bool, date, datetime, dict, float, int, list, str, none_type)}],),
                'auth': [],
                'endpoint_path': '/statistics/process/counters',
                'operation_id': 'get_statistics_processing_counters',
                'http_method': 'GET',
                'servers': None,
            },
            params_map={
                'all': [
                ],
                'required': [],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                },
                'attribute_map': {
                },
                'location_map': {
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [],
            },
            api_client=api_client
        )
        self.process_statistics_data_endpoint = _Endpoint(
            settings={
                'response_type': ({str: (bool, date, datetime, dict, float, int, list, str, none_type)},),
                'auth': [],
                'endpoint_path': '/statistics/process',
                'operation_id': 'process_statistics_data',
                'http_method': 'GET',
                'servers': None,
            },
            params_map={
                'all': [
                ],
                'required': [],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                },
                'attribute_map': {
                },
                'location_map': {
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [],
            },
            api_client=api_client
        )
        self.reset_stats_collection_endpoint = _Endpoint(
            settings={
                'response_type': ({str: (bool, date, datetime, dict, float, int, list, str, none_type)},),
                'auth': [],
                'endpoint_path': '/statistics/collection/reset/{processQueue}',
                'operation_id': 'reset_stats_collection',
                'http_method': 'GET',
                'servers': None,
            },
            params_map={
                'all': [
                    'process_queue',
                ],
                'required': [
                    'process_queue',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'process_queue':
                        (int,),
                },
                'attribute_map': {
                    'process_queue': 'processQueue',
                },
                'location_map': {
                    'process_queue': 'path',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [],
            },
            api_client=api_client
        )
        self.start_stats_collection_endpoint = _Endpoint(
            settings={
                'response_type': ({str: (bool, date, datetime, dict, float, int, list, str, none_type)},),
                'auth': [],
                'endpoint_path': '/statistics/collect',
                'operation_id': 'start_stats_collection',
                'http_method': 'GET',
                'servers': None,
            },
            params_map={
                'all': [
                ],
                'required': [],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                },
                'attribute_map': {
                },
                'location_map': {
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [],
            },
            api_client=api_client
        )

    def enable_statistics_demo_mode(
        self,
        **kwargs
    ):
        """enable_statistics_demo_mode  # noqa: E501

        Enable statistic demo mode  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.enable_statistics_demo_mode(async_req=True)
        >>> result = thread.get()


        Keyword Args:
            enable (bool): Demo mode flag. [optional] if omitted the server will use the default value of True
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            _request_auths (list): set to override the auth_settings for an a single
                request; this effectively ignores the authentication
                in the spec for a single request.
                Default is None
            async_req (bool): execute request asynchronously

        Returns:
            {str: (bool, date, datetime, dict, float, int, list, str, none_type)}
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['_request_auths'] = kwargs.get('_request_auths', None)
        return self.enable_statistics_demo_mode_endpoint.call_with_http_info(**kwargs)

    def generate_stats_collect_thread_report(
        self,
        **kwargs
    ):
        """generate_stats_collect_thread_report  # noqa: E501

        Get stats collect thread report  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.generate_stats_collect_thread_report(async_req=True)
        >>> result = thread.get()


        Keyword Args:
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            _request_auths (list): set to override the auth_settings for an a single
                request; this effectively ignores the authentication
                in the spec for a single request.
                Default is None
            async_req (bool): execute request asynchronously

        Returns:
            [{str: (bool, date, datetime, dict, float, int, list, str, none_type)}]
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['_request_auths'] = kwargs.get('_request_auths', None)
        return self.generate_stats_collect_thread_report_endpoint.call_with_http_info(**kwargs)

    def generate_stats_process_report(
        self,
        **kwargs
    ):
        """generate_stats_process_report  # noqa: E501

        Get stats process report  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.generate_stats_process_report(async_req=True)
        >>> result = thread.get()


        Keyword Args:
            process_queue (int): Process queue. [optional]
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            _request_auths (list): set to override the auth_settings for an a single
                request; this effectively ignores the authentication
                in the spec for a single request.
                Default is None
            async_req (bool): execute request asynchronously

        Returns:
            [{str: (bool, date, datetime, dict, float, int, list, str, none_type)}]
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['_request_auths'] = kwargs.get('_request_auths', None)
        return self.generate_stats_process_report_endpoint.call_with_http_info(**kwargs)

    def generate_stats_process_thread_report(
        self,
        **kwargs
    ):
        """generate_stats_process_thread_report  # noqa: E501

        Get stats process thread report  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.generate_stats_process_thread_report(async_req=True)
        >>> result = thread.get()


        Keyword Args:
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            _request_auths (list): set to override the auth_settings for an a single
                request; this effectively ignores the authentication
                in the spec for a single request.
                Default is None
            async_req (bool): execute request asynchronously

        Returns:
            [{str: (bool, date, datetime, dict, float, int, list, str, none_type)}]
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['_request_auths'] = kwargs.get('_request_auths', None)
        return self.generate_stats_process_thread_report_endpoint.call_with_http_info(**kwargs)

    def get_statistic_type(
        self,
        **kwargs
    ):
        """get_statistic_type  # noqa: E501

        Get statistics types  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_statistic_type(async_req=True)
        >>> result = thread.get()


        Keyword Args:
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            _request_auths (list): set to override the auth_settings for an a single
                request; this effectively ignores the authentication
                in the spec for a single request.
                Default is None
            async_req (bool): execute request asynchronously

        Returns:
            [{str: (bool, date, datetime, dict, float, int, list, str, none_type)}]
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['_request_auths'] = kwargs.get('_request_auths', None)
        return self.get_statistic_type_endpoint.call_with_http_info(**kwargs)

    def get_statistics_processing_counters(
        self,
        **kwargs
    ):
        """get_statistics_processing_counters  # noqa: E501

        Get statistics processing counters  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_statistics_processing_counters(async_req=True)
        >>> result = thread.get()


        Keyword Args:
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            _request_auths (list): set to override the auth_settings for an a single
                request; this effectively ignores the authentication
                in the spec for a single request.
                Default is None
            async_req (bool): execute request asynchronously

        Returns:
            [{str: (bool, date, datetime, dict, float, int, list, str, none_type)}]
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['_request_auths'] = kwargs.get('_request_auths', None)
        return self.get_statistics_processing_counters_endpoint.call_with_http_info(**kwargs)

    def process_statistics_data(
        self,
        **kwargs
    ):
        """process_statistics_data  # noqa: E501

        Process stats data  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.process_statistics_data(async_req=True)
        >>> result = thread.get()


        Keyword Args:
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            _request_auths (list): set to override the auth_settings for an a single
                request; this effectively ignores the authentication
                in the spec for a single request.
                Default is None
            async_req (bool): execute request asynchronously

        Returns:
            {str: (bool, date, datetime, dict, float, int, list, str, none_type)}
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['_request_auths'] = kwargs.get('_request_auths', None)
        return self.process_statistics_data_endpoint.call_with_http_info(**kwargs)

    def reset_stats_collection(
        self,
        process_queue=-1,
        **kwargs
    ):
        """reset_stats_collection  # noqa: E501

        Reset stats collect thread report  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.reset_stats_collection(process_queue=-1, async_req=True)
        >>> result = thread.get()

        Args:
            process_queue (int): Process queue. defaults to -1, must be one of [-1]

        Keyword Args:
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            _request_auths (list): set to override the auth_settings for an a single
                request; this effectively ignores the authentication
                in the spec for a single request.
                Default is None
            async_req (bool): execute request asynchronously

        Returns:
            {str: (bool, date, datetime, dict, float, int, list, str, none_type)}
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['_request_auths'] = kwargs.get('_request_auths', None)
        kwargs['process_queue'] = \
            process_queue
        return self.reset_stats_collection_endpoint.call_with_http_info(**kwargs)

    def start_stats_collection(
        self,
        **kwargs
    ):
        """start_stats_collection  # noqa: E501

        Start stats collect  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.start_stats_collection(async_req=True)
        >>> result = thread.get()


        Keyword Args:
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            _request_auths (list): set to override the auth_settings for an a single
                request; this effectively ignores the authentication
                in the spec for a single request.
                Default is None
            async_req (bool): execute request asynchronously

        Returns:
            {str: (bool, date, datetime, dict, float, int, list, str, none_type)}
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['_request_auths'] = kwargs.get('_request_auths', None)
        return self.start_stats_collection_endpoint.call_with_http_info(**kwargs)




"""
    Cisco SD-WAN vManage API

    The vManage API exposes the functionality of operations maintaining devices and the overlay network  # noqa: E501

    The version of the OpenAPI document: 2.0.0
    Contact: vmanage@cisco.com
    Generated by: https://openapi-generator.tech
"""


import unittest

import openapi_client
from openapi_client.api.real_time_monitoring_omp_api import RealTimeMonitoringOMPApi  # noqa: E501


class TestRealTimeMonitoringOMPApi(unittest.TestCase):
    """RealTimeMonitoringOMPApi unit test stubs"""

    def setUp(self):
        self.api = RealTimeMonitoringOMPApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_create_advertised_routes_list(self):
        """Test case for create_advertised_routes_list

        """
        pass

    def test_create_advertised_routes_list_ipv6(self):
        """Test case for create_advertised_routes_list_ipv6

        """
        pass

    def test_create_advertised_tlocs_list(self):
        """Test case for create_advertised_tlocs_list

        """
        pass

    def test_create_omp_cloud_x_recv(self):
        """Test case for create_omp_cloud_x_recv

        """
        pass

    def test_create_omp_link_list(self):
        """Test case for create_omp_link_list

        """
        pass

    def test_create_omp_mcast_auto_discover_advt(self):
        """Test case for create_omp_mcast_auto_discover_advt

        """
        pass

    def test_create_omp_mcast_auto_discover_recv(self):
        """Test case for create_omp_mcast_auto_discover_recv

        """
        pass

    def test_create_omp_mcast_routes_advt(self):
        """Test case for create_omp_mcast_routes_advt

        """
        pass

    def test_create_omp_mcast_routes_recv(self):
        """Test case for create_omp_mcast_routes_recv

        """
        pass

    def test_create_omp_services(self):
        """Test case for create_omp_services

        """
        pass

    def test_create_omp_session_list(self):
        """Test case for create_omp_session_list

        """
        pass

    def test_create_omp_summary(self):
        """Test case for create_omp_summary

        """
        pass

    def test_create_received_routes_list(self):
        """Test case for create_received_routes_list

        """
        pass

    def test_create_received_routes_list_ipv6(self):
        """Test case for create_received_routes_list_ipv6

        """
        pass

    def test_create_received_tlocs_list(self):
        """Test case for create_received_tlocs_list

        """
        pass

    def test_create_synced_omp_session_list(self):
        """Test case for create_synced_omp_session_list

        """
        pass

    def test_get_device_omp_status(self):
        """Test case for get_device_omp_status

        """
        pass


if __name__ == '__main__':
    unittest.main()



"""
    Cisco SD-WAN vManage API

    The vManage API exposes the functionality of operations maintaining devices and the overlay network  # noqa: E501

    The version of the OpenAPI document: 2.0.0
    Contact: vmanage@cisco.com
    Generated by: https://openapi-generator.tech
"""


import unittest

import openapi_client
from openapi_client.api.real_time_monitoring_device_control_api import RealTimeMonitoringDeviceControlApi  # noqa: E501


class TestRealTimeMonitoringDeviceControlApi(unittest.TestCase):
    """RealTimeMonitoringDeviceControlApi unit test stubs"""

    def setUp(self):
        self.api = RealTimeMonitoringDeviceControlApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_create_connection_history_list_real_time(self):
        """Test case for create_connection_history_list_real_time

        """
        pass

    def test_create_connections_summary(self):
        """Test case for create_connections_summary

        """
        pass

    def test_create_link_list(self):
        """Test case for create_link_list

        """
        pass

    def test_create_local_properties_list_list_real_t_ime(self):
        """Test case for create_local_properties_list_list_real_t_ime

        """
        pass

    def test_create_local_properties_synced_list(self):
        """Test case for create_local_properties_synced_list

        """
        pass

    def test_create_real_time_connection_list(self):
        """Test case for create_real_time_connection_list

        """
        pass

    def test_create_synced_connection_list(self):
        """Test case for create_synced_connection_list

        """
        pass

    def test_create_valid_devices_list_real_time(self):
        """Test case for create_valid_devices_list_real_time

        """
        pass

    def test_create_valid_v_smarts_list_real_time(self):
        """Test case for create_valid_v_smarts_list_real_time

        """
        pass

    def test_create_wan_interface_list_list(self):
        """Test case for create_wan_interface_list_list

        """
        pass

    def test_create_wan_interface_synced_list(self):
        """Test case for create_wan_interface_synced_list

        """
        pass

    def test_get_affinity_config(self):
        """Test case for get_affinity_config

        """
        pass

    def test_get_affinity_status(self):
        """Test case for get_affinity_status

        """
        pass

    def test_get_connection_statistics(self):
        """Test case for get_connection_statistics

        """
        pass

    def test_get_device_control_status_summary(self):
        """Test case for get_device_control_status_summary

        """
        pass

    def test_get_local_device_status(self):
        """Test case for get_local_device_status

        """
        pass

    def test_get_port_hop_color(self):
        """Test case for get_port_hop_color

        """
        pass

    def test_get_total_count_for_device_states(self):
        """Test case for get_total_count_for_device_states

        """
        pass

    def test_get_valid_v_manage_id_real_time(self):
        """Test case for get_valid_v_manage_id_real_time

        """
        pass

    def test_network_summary(self):
        """Test case for network_summary

        """
        pass


if __name__ == '__main__':
    unittest.main()



"""
    Cisco SD-WAN vManage API

    The vManage API exposes the functionality of operations maintaining devices and the overlay network  # noqa: E501

    The version of the OpenAPI document: 2.0.0
    Contact: vmanage@cisco.com
    Generated by: https://openapi-generator.tech
"""


import unittest

import openapi_client
from openapi_client.api.deployment_mode_api import DeploymentModeApi  # noqa: E501


class TestDeploymentModeApi(unittest.TestCase):
    """DeploymentModeApi unit test stubs"""

    def setUp(self):
        self.api = DeploymentModeApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_config_fedramp_mode(self):
        """Test case for config_fedramp_mode

        """
        pass

    def test_configure_dns_sec(self):
        """Test case for configure_dns_sec

        """
        pass

    def test_configure_wazuh_client(self):
        """Test case for configure_wazuh_client

        """
        pass

    def test_get_dns_sec_status(self):
        """Test case for get_dns_sec_status

        """
        pass

    def test_get_wazuh_agent_status(self):
        """Test case for get_wazuh_agent_status

        """
        pass

    def test_reques_dns_sec_actions(self):
        """Test case for reques_dns_sec_actions

        """
        pass

    def test_request_wazuh_actions(self):
        """Test case for request_wazuh_actions

        """
        pass


if __name__ == '__main__':
    unittest.main()



"""
    Cisco SD-WAN vManage API

    The vManage API exposes the functionality of operations maintaining devices and the overlay network  # noqa: E501

    The version of the OpenAPI document: 2.0.0
    Contact: vmanage@cisco.com
    Generated by: https://openapi-generator.tech
"""


import unittest

import openapi_client
from openapi_client.api.monitoring_alarms_details_api import MonitoringAlarmsDetailsApi  # noqa: E501


class TestMonitoringAlarmsDetailsApi(unittest.TestCase):
    """MonitoringAlarmsDetailsApi unit test stubs"""

    def setUp(self):
        self.api = MonitoringAlarmsDetailsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_clear_stale_alarm(self):
        """Test case for clear_stale_alarm

        """
        pass

    def test_correl_anti_entropy(self):
        """Test case for correl_anti_entropy

        """
        pass

    def test_create_alarm_query_config(self):
        """Test case for create_alarm_query_config

        """
        pass

    def test_create_notification_rule(self):
        """Test case for create_notification_rule

        """
        pass

    def test_delete_notification_rule(self):
        """Test case for delete_notification_rule

        """
        pass

    def test_disable_enable_alarm(self):
        """Test case for disable_enable_alarm

        """
        pass

    def test_dump_correlation_engine_data(self):
        """Test case for dump_correlation_engine_data

        """
        pass

    def test_enable_disable_link_state_alarm(self):
        """Test case for enable_disable_link_state_alarm

        """
        pass

    def test_get_alarm_aggregation_data(self):
        """Test case for get_alarm_aggregation_data

        """
        pass

    def test_get_alarm_details(self):
        """Test case for get_alarm_details

        """
        pass

    def test_get_alarm_severity_custom_histogram(self):
        """Test case for get_alarm_severity_custom_histogram

        """
        pass

    def test_get_alarm_severity_mappings(self):
        """Test case for get_alarm_severity_mappings

        """
        pass

    def test_get_alarm_types_as_key_value(self):
        """Test case for get_alarm_types_as_key_value

        """
        pass

    def test_get_alarms(self):
        """Test case for get_alarms

        """
        pass

    def test_get_alarms_by_severity(self):
        """Test case for get_alarms_by_severity

        """
        pass

    def test_get_count1(self):
        """Test case for get_count1

        """
        pass

    def test_get_count_post1(self):
        """Test case for get_count_post1

        """
        pass

    def test_get_device_topic(self):
        """Test case for get_device_topic

        """
        pass

    def test_get_link_state_alarm_config(self):
        """Test case for get_link_state_alarm_config

        """
        pass

    def test_get_master_manager_state(self):
        """Test case for get_master_manager_state

        """
        pass

    def test_get_non_viewed_active_alarms_count(self):
        """Test case for get_non_viewed_active_alarms_count

        """
        pass

    def test_get_non_viewed_alarms(self):
        """Test case for get_non_viewed_alarms

        """
        pass

    def test_get_notification_rule(self):
        """Test case for get_notification_rule

        """
        pass

    def test_get_post_alarm_aggregation_data(self):
        """Test case for get_post_alarm_aggregation_data

        """
        pass

    def test_get_post_stat_bulk_alarm_raw_data(self):
        """Test case for get_post_stat_bulk_alarm_raw_data

        """
        pass

    def test_get_raw_alarm_data(self):
        """Test case for get_raw_alarm_data

        """
        pass

    def test_get_stat_bulk_alarm_raw_data(self):
        """Test case for get_stat_bulk_alarm_raw_data

        """
        pass

    def test_get_stat_data_fields1(self):
        """Test case for get_stat_data_fields1

        """
        pass

    def test_get_stat_query_fields1(self):
        """Test case for get_stat_query_fields1

        """
        pass

    def test_get_stats(self):
        """Test case for get_stats

        """
        pass

    def test_list_disabled_alarm(self):
        """Test case for list_disabled_alarm

        """
        pass

    def test_mark_alarms_as_viewed(self):
        """Test case for mark_alarms_as_viewed

        """
        pass

    def test_mark_all_alarms_as_viewed(self):
        """Test case for mark_all_alarms_as_viewed

        """
        pass

    def test_restart_correlation_engine(self):
        """Test case for restart_correlation_engine

        """
        pass

    def test_set_periodic_purge_timer(self):
        """Test case for set_periodic_purge_timer

        """
        pass

    def test_start_tracking(self):
        """Test case for start_tracking

        """
        pass

    def test_stop_tracking(self):
        """Test case for stop_tracking

        """
        pass

    def test_update_notification_rule(self):
        """Test case for update_notification_rule

        """
        pass


if __name__ == '__main__':
    unittest.main()



"""
    Cisco SD-WAN vManage API

    The vManage API exposes the functionality of operations maintaining devices and the overlay network  # noqa: E501

    The version of the OpenAPI document: 2.0.0
    Contact: vmanage@cisco.com
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import openapi_client
from openapi_client.model.control_status import ControlStatus
from openapi_client.model.site_health import SiteHealth
from openapi_client.model.v_edge_health import VEdgeHealth
from openapi_client.model.v_smart_status import VSmartStatus
globals()['ControlStatus'] = ControlStatus
globals()['SiteHealth'] = SiteHealth
globals()['VEdgeHealth'] = VEdgeHealth
globals()['VSmartStatus'] = VSmartStatus
from openapi_client.model.tenant_status import TenantStatus


class TestTenantStatus(unittest.TestCase):
    """TenantStatus unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testTenantStatus(self):
        """Test TenantStatus"""
        # FIXME: construct object with mandatory attributes with example values
        # model = TenantStatus()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()



"""
    Cisco SD-WAN vManage API

    The vManage API exposes the functionality of operations maintaining devices and the overlay network  # noqa: E501

    The version of the OpenAPI document: 2.0.0
    Contact: vmanage@cisco.com
    Generated by: https://openapi-generator.tech
"""


import unittest

import openapi_client
from openapi_client.api.colocation_service_group_api import ColocationServiceGroupApi  # noqa: E501


class TestColocationServiceGroupApi(unittest.TestCase):
    """ColocationServiceGroupApi unit test stubs"""

    def setUp(self):
        self.api = ColocationServiceGroupApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_create_service_group_cluster(self):
        """Test case for create_service_group_cluster

        """
        pass

    def test_delete_service_group_cluster(self):
        """Test case for delete_service_group_cluster

        """
        pass

    def test_get_available_chains(self):
        """Test case for get_available_chains

        """
        pass

    def test_get_default_chain(self):
        """Test case for get_default_chain

        """
        pass

    def test_get_service_chain(self):
        """Test case for get_service_chain

        """
        pass

    def test_get_service_group_in_cluster(self):
        """Test case for get_service_group_in_cluster

        """
        pass

    def test_update_service_group_cluster(self):
        """Test case for update_service_group_cluster

        """
        pass


if __name__ == '__main__':
    unittest.main()
